package jdk.javadoc.internal.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "11.0.20.1+1" },
            { "jdk", "11.0.20.1" },
            { "release", "11.0.20.1" },
        };
    }
}
